==> gmahomology_1.12.0.tar.gz: gmahomology/man/gmahomologyLL2HGID.Rd <==
\name{gmahomologyLL2HGID}
\alias{gmahomologyLL2HGID}
\alias{gmahomologyACC2HGID}
\alias{gmahomologyHGID2LL}
\alias{gmahomologyHGID2ACC} 
\title{Mappings between public database ids and NCBI's Internal
  HomoloGeneIDs for Glycine max}  
\description{
  R environments that provides mappings between public database ids and internal
  HomoloGeneIDs (HGID) used by NCBI to represent sequences for
  Glycine max. Public database ids include LocusLink ids (LL) and GenBank
  Accesion/RefSeq numbers (ACC).     
}
\details{
  Each R environment provides mapping between either HomoloGeneIds and
  database ids, or the converse. The mapping direction is indicated by
  the name of the environment. For instance, gmahomologyACC2HGID provides
  mappings between GenBank accession numbers and HomoloGeneIds.

  For each environment, a given id will map to a named vector of ids,
  the names of which are the NCBI code for that organism.
 
  Mappings contained were based on data provided by HomoloGene.
  
  HomoloGene:\url{ ftp://ftp.ncbi.nih.gov/pub/HomoloGene/old/hmlg.ftp}. Built: HomoloGene built date not available

  Packagebuilt Sat Mar 25 23:28:52 2006
}
\references{
\url{http://www.ncbi.nih.gov/entrez/query.fcgi?db=homologene}
}
\examples{
    require("annotate") || stop("annotate unavailable")
    xx <- as.list(gmahomologyLL2HGID)
        if(length(xx) > 5){
                # Get the value of the first key
                xx[2]
                # Get the value for a few keys
                if(length(xx) >= 3){
                        xx[2:4]
                }
        }
}
\keyword{datasets}

==> gmahomology_1.14.2.tar.gz: gmahomology/man/gmahomologyLL2HGID.Rd <==
\name{gmahomologyLL2HGID}
\alias{gmahomologyLL2HGID}
\alias{gmahomologyACC2HGID}
\alias{gmahomologyHGID2LL}
\alias{gmahomologyHGID2ACC} 
\title{Mappings between public database identifiers and NCBI's Internal
  HomoloGeneIDs for Glycine max}  
\description{
  R environments that provides mappings between public database identifiers and internal
  HomoloGeneIDs (HGID) used by NCBI to represent sequences for
  Glycine max. Public database identifiers include Entrez Gene identifiers (LL) and GenBank
  Accesion/RefSeq numbers (ACC).     
}
\details{
  Each R environment provides mapping between either HomoloGeneIds and
  database identifiers. or the converse. The mapping direction is indicated by
  the name of the environment. For instance, gmahomologyACC2HGID provides
  mappings between GenBank accession numbers and HomoloGeneIds.

  For each environment, a given identifier will map to a named vector of identifiers.
  the names of which are the NCBI code for that organism.
 
  Mappings contained were based on data provided by HomoloGene.
  
  HomoloGene:\\url{ ftp://ftp.ncbi.nih.gov/pub/HomoloGene/old/hmlg.ftp}. Built: HomoloGene built date not available

  Packagebuilt Tue Nov 21 17:11:36 2006
}
\references{
\url{http://www.ncbi.nih.gov/entrez/query.fcgi?db=homologene}
}
\examples{
    require("annotate") || stop("annotate unavailable")
    xx <- as.list(gmahomologyLL2HGID)
        if(length(xx) > 5){
                # Get the value of the first key
                xx[2]
                # Get the value for a few keys
                if(length(xx) >= 3){
                        xx[2:4]
                }
        }
}
\keyword{datasets}
